# coding: utf-8

"""
    Harmony Connect

    An easy to use API that helps you access the Factom blockchain.  # noqa: E501

    OpenAPI spec version: 1.0.17
    Contact: harmony-support@factom.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class EntrySearchResponseData(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'entry_hash': 'str',
        'external_ids': 'list[str]',
        'stage': 'str',
        'href': 'str'
    }

    attribute_map = {
        'entry_hash': 'entry_hash',
        'external_ids': 'external_ids',
        'stage': 'stage',
        'href': 'href'
    }

    def __init__(self, entry_hash=None, external_ids=None, stage=None, href=None):  # noqa: E501
        """EntrySearchResponseData - a model defined in OpenAPI"""  # noqa: E501

        self._entry_hash = None
        self._external_ids = None
        self._stage = None
        self._href = None
        self.discriminator = None

        self.entry_hash = entry_hash
        self.external_ids = external_ids
        self.stage = stage
        self.href = href

    @property
    def entry_hash(self):
        """Gets the entry_hash of this EntrySearchResponseData.  # noqa: E501

        The SHA256 Hash of this entry.  # noqa: E501

        :return: The entry_hash of this EntrySearchResponseData.  # noqa: E501
        :rtype: str
        """
        return self._entry_hash

    @entry_hash.setter
    def entry_hash(self, entry_hash):
        """Sets the entry_hash of this EntrySearchResponseData.

        The SHA256 Hash of this entry.  # noqa: E501

        :param entry_hash: The entry_hash of this EntrySearchResponseData.  # noqa: E501
        :type: str
        """
        if entry_hash is None:
            raise ValueError("Invalid value for `entry_hash`, must not be `None`")  # noqa: E501

        self._entry_hash = entry_hash

    @property
    def external_ids(self):
        """Gets the external_ids of this EntrySearchResponseData.  # noqa: E501

        Tags that can be used to identify this entry.  # noqa: E501

        :return: The external_ids of this EntrySearchResponseData.  # noqa: E501
        :rtype: list[str]
        """
        return self._external_ids

    @external_ids.setter
    def external_ids(self, external_ids):
        """Sets the external_ids of this EntrySearchResponseData.

        Tags that can be used to identify this entry.  # noqa: E501

        :param external_ids: The external_ids of this EntrySearchResponseData.  # noqa: E501
        :type: list[str]
        """
        if external_ids is None:
            raise ValueError("Invalid value for `external_ids`, must not be `None`")  # noqa: E501

        self._external_ids = external_ids

    @property
    def stage(self):
        """Gets the stage of this EntrySearchResponseData.  # noqa: E501

        The level of immutability that this entry has reached.  # noqa: E501

        :return: The stage of this EntrySearchResponseData.  # noqa: E501
        :rtype: str
        """
        return self._stage

    @stage.setter
    def stage(self, stage):
        """Sets the stage of this EntrySearchResponseData.

        The level of immutability that this entry has reached.  # noqa: E501

        :param stage: The stage of this EntrySearchResponseData.  # noqa: E501
        :type: str
        """
        if stage is None:
            raise ValueError("Invalid value for `stage`, must not be `None`")  # noqa: E501

        self._stage = stage

    @property
    def href(self):
        """Gets the href of this EntrySearchResponseData.  # noqa: E501

        An API link to retrieve all information about this entry.  # noqa: E501

        :return: The href of this EntrySearchResponseData.  # noqa: E501
        :rtype: str
        """
        return self._href

    @href.setter
    def href(self, href):
        """Sets the href of this EntrySearchResponseData.

        An API link to retrieve all information about this entry.  # noqa: E501

        :param href: The href of this EntrySearchResponseData.  # noqa: E501
        :type: str
        """
        if href is None:
            raise ValueError("Invalid value for `href`, must not be `None`")  # noqa: E501

        self._href = href

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EntrySearchResponseData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
