# coding: utf-8

"""
    Harmony Connect

    An easy to use API that helps you access the Factom blockchain.  # noqa: E501

    OpenAPI spec version: 1.0.17
    Contact: harmony-support@factom.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import harmony_connect_client
from harmony_connect_client.api.entries_api import EntriesApi  # noqa: E501
from harmony_connect_client.rest import ApiException


class TestEntriesApi(unittest.TestCase):
    """EntriesApi unit test stubs"""

    def setUp(self):
        self.api = harmony_connect_client.api.entries_api.EntriesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_entries_by_chain_id(self):
        """Test case for get_entries_by_chain_id

        Get Chain's Entries  # noqa: E501
        """
        pass

    def test_get_entry_by_hash(self):
        """Test case for get_entry_by_hash

        Get Entry Info  # noqa: E501
        """
        pass

    def test_get_first_entry(self):
        """Test case for get_first_entry

        Get Chain's First Entry  # noqa: E501
        """
        pass

    def test_get_last_entry(self):
        """Test case for get_last_entry

        Get Chain's Last Entry  # noqa: E501
        """
        pass

    def test_post_entries_search(self):
        """Test case for post_entries_search

        Search Chain's Entries  # noqa: E501
        """
        pass

    def test_post_entry_to_chain_id(self):
        """Test case for post_entry_to_chain_id

        Create an Entry  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
