# coding: utf-8

"""
    Harmony Connect

    An easy to use API that helps you access the Factom blockchain.  # noqa: E501

    OpenAPI spec version: 1.0.17
    Contact: harmony-support@factom.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import harmony_connect_client
from harmony_connect_client.models.chain_data_eblock import ChainDataEblock  # noqa: E501
from harmony_connect_client.rest import ApiException


class TestChainDataEblock(unittest.TestCase):
    """ChainDataEblock unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testChainDataEblock(self):
        """Test ChainDataEblock"""
        # FIXME: construct object with mandatory attributes with example values
        # model = harmony_connect_client.models.chain_data_eblock.ChainDataEblock()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
